#! /usr/bin/perl -w

#
# Parts based on nwsxml.pl by Lucien Dunning
# TODO: Conversion of units. Currently the units are ignored

use strict;
use XML::Simple;
use LWP::UserAgent;
# Ideally we would use the If-Modified-Since header
# to reduce server load, but they ignore it
#use HTTP::Cache::Transparent;
use Getopt::Std;
use File::Basename;
use lib dirname($0);




our ($opt_v, $opt_t, $opt_T, $opt_l, $opt_u, $opt_d);

my (%mythoutput,$value,$keyword);

my $name = 'Accu.com-Current';
my $version = 0.2;
my $author = 'Marcel Verpaalen';
# modified by gilles74 - mythtv-fr
#my $email = 'marcel.verpaalen@gmail.com';
my $email = ' ';

# Basic options
     my $updateTimeout = 120*60;
     my $retrieveTimeout = 30;
     my @types = ('cclocation', 'station_id', 'copyright', 'daycode',
        	'observation_time', 'weather', 'temp', 'relative_humidity',
        	'wind_dir', 'pressure', 'visibility', 'weather_icon',
        	'appt', 'wind_spdgst', 
	'3dlocation', 
        	'date-0', 'icon-0', 'low-0', 'high-0',
        	'date-1', 'icon-1', 'low-1', 'high-1', 
        	'date-2', 'icon-2', 'low-2', 'high-2', 'updatetime',
	'6dlocation', 
		'date-3', 'icon-3', 'low-3', 'high-3',
        	'date-4', 'icon-4', 'low-4', 'high-4',
        	'date-5', 'icon-5', 'low-5', 'high-5', 
		);

      my $dir = "./";


# definition des options
getopts('Tvtlu:d:');

     # option v  -  script informations
          if (defined $opt_v) {
              print "$name,$version,$author,$email\n";
          exit 0;
          }
     # option T  -  delay values
          if (defined $opt_T) {
              print "$updateTimeout,$retrieveTimeout\n";
          exit 0;
          }
     # option l -search location
          if (defined $opt_l) {
              my $search = shift;
              my $location_base_url = 'http://forecastfox.accuweather.com/adcbin/forecastfox/locate_city.asp?location=';

              my $ua = LWP::UserAgent->new;
                 $ua->timeout(20);
                 $ua->env_proxy;
                 $ua->agent('Mozilla/5.0');

              my $response = $ua->get($location_base_url . $search);
                 die unless defined $response;
              my $xml = XMLin($response->decoded_content );

              if (!$xml) {
                   die "Not xml";
              }

              foreach my $item (@{$xml->{citylist}->{location}}){
                 printf "%s::%s", $item->{location},  $item->{city} . ", " .  $item->{state} . "\n" ; 
              }
              exit 0;
          }


    # Option t  - give used items 
         if (defined $opt_t) {
             foreach (@types) {print; print "\n";}
             exit 0;
         }

   # Option d  - defined the directory for the cache
        if (defined $opt_d) {
             $dir = $opt_d;
        }



# main program - download data

my $locid = shift;

# we get here, we're doing an actual retrieval, everything must be defined
	if (!(defined $opt_u && defined $locid && !$locid eq "")) {
	    die "Invalid usage";
	}

	my $units = $opt_u;

	my $type;
foreach $type (@types){$mythoutput{$type}='N/A' ;};

	my $url = 'http://forecastfox.accuweather.com/adcbin/forecastfox/weather_data.asp?metric=1&partner=forecastfox&location=';

	my $base_url = "$url$locid" ;


	 my $ua = LWP::UserAgent->new;
	 $ua->timeout(20);
 	$ua->env_proxy;
 #	$ua->put_ToCharset("iso-8859-1");
 #	$ua->put_from_ToCharset("utf-8"); 	
 #	$ua->ConvertFile();
 	$ua->agent('Mozilla/5.0');


 	my $response = $ua->get($base_url);
 
 #	if ($response->is_success) {

#	 }
#	 else {
# 	    die $response->status_line;
#	 }
 

	my $xml = XMLin($response->decoded_content );

	if (!$xml) {
	    die "Not xml";
	}

    # Conversion of keys accuweather->Myth
           my %conv  = ("temperature","temp",
			"weathertext","weather",
			"winddirection","wind_dir",
			"windgusts","wind_gust",
			"humidity", "relative_humidity",
			"visibility","visibility",
			"pressure","pressure",
			"realfeel","appt",
			"weathericon","weather_icon",
			"windspeed","wind_spdgst");


    # header data
           $mythoutput{"copyright"} = $xml->{copyright};
           $mythoutput{"station_id"} = $locid ;
           $mythoutput{"cclocation"} = $xml->{local}->{city} . ", " . $xml->{local}->{state} ;
           $mythoutput{"3dlocation"} = $xml->{local}->{city} . ", " . $xml->{local}->{state} ;
           $mythoutput{"6dlocation"} = $xml->{local}->{city} . ", " . $xml->{local}->{state} ;
           $mythoutput{"observation_time"} = "Observations du : " . $xml->{forecast}->{day}->[0]->{obsdate} . " " . $xml->{local}->{time} ;
           $mythoutput{"updatetime"} = "Prvisions du : " . $xml->{forecast}->{day}->[0]->{obsdate} . " " . $xml->{local}->{time} ;


   # Current conditions
	foreach my $key (keys (%{$xml->{currentconditions}})){

	   if ( exists $conv {$key}  ) {
	        $value = $xml->{currentconditions}->{$key};
	   if (ref($value) eq 'HASH'){
		$mythoutput{$conv {$key}} = $value->{content} ;}
	   else {
		$mythoutput{$conv {$key}} = $value ;
		}
	      #printf $conv {$key}  . "::%s" . "\n" , $xml->{currentconditions}->{$key} ;
	   }  
	   else {
		# printf "Not processed: " . $key . "=%s" . "\n" ,  $xml->{currentconditions}->{$key} ;
	        }
           }

  # day mappings to be made
        my %daycodes = ("Monday","Lundi",
	                "Tuesday","Mardi",
	                "Wednesday","Mercredi",
	                "Thursday","Jeudi",
	                "Friday","Vendredi",
	                "Saturday","Samedi",
	                "Sunday","Dimanche");

  # conversions days/ mapping
        if ( exists $daycodes { $mythoutput {"daycode"}}) {
	      $mythoutput {"daycode"} = $daycodes {$mythoutput {"daycode"}}; }
        else { $mythoutput {"daycode"} = "Jour Inconnu" ; };
    
  # wind direction mappings to be made
        my %wind_dirs = ("N","Nord",
			"NNE", "Nord-nord-est",
			"NE","Nord-est",
			"ENE", "Est-nord-est",
	                "E","Est",
			"ESE","Est-sud-est",
			"SE", "Sud-est",
			"SSE","Sud-sud-est",
	                "S","Sud",
			"SSW","Sud-sud-ouest",
			"SW", "Sud-ouest",
			"WSW","Ouest-sud-ouest",
			"W","Ouest",                
			"WNW","Ouest-nord-ouest",
	                "NW","Nord-ouest",
			"NNW","Nord-nord-ouest",
			"CLM","Variable");

  # conversions wind direction/ mapping
        if ( exists $wind_dirs { $mythoutput {"wind_dir"}}) {
	      $mythoutput {"wind_dir"} = $wind_dirs {$mythoutput {"wind_dir"}}; }
        else  { };
    
  #weathers mappings to be made
  #Translation available:"English","French","Dutch","German","Traditional chinese","Slovak","Russian","Greek"
  #By The_RedBurn    http://extensions.geckozone.org/The_RedBurn

       my %weathers = ("Cloudy and Cold","Nuageux et froid",
	"A Few Clouds","Quelques nuages",#  				"Weinig bewolking","gering bewlkt","??","Mal obla?nos?","???????????????? ??????","????????? ????"
	"AM Clouds / PM Sun","Nuageux dans la matine / Soleil dans l'aprs-midi",#  				"Bewolkt in de ochtend, zon in de middag","vormittags bewlkt, nachmittags sonnig","????/???","Dopoludnia zamra?en / Popoludn slne?no","?????? ?? ??????? / ?????? ????? ???????","?? ????????? / ?? ??????????"
	"AM Clouds / PM Sun / Wind","Nuageux dans la matine / Soleil dans l'aprs-midi / Vent",#  				"Bewolkt in de ochtend, zon en wind in de middag","vormittags bewlkt, nachmittags sonnig und windig","??????????","Dopoludnia zamra?en / Popoludn slne?no / Vietor","?????? ?? ??????? / ?????? ????? ??????? / ?????","?? ????????? / ?? ?????????? / ??????"
	"AM Drizzle","Bruine dans la matine",#  				"Motregen in de ochtend","vormittags Nieselregen","?????","Dopoludnia mrholenie","???????? ?? ???????","?? ??????"
	"AM Fog / PM Sun","Brouillard dans la matine / Soleil dans l'aprs-midi",#  				"Mist in de ochtend, zon in de middag","vormittags Nebel, nachmittags sonnig",,,,
	"AM Fog / PM Clouds","Brouillard dans la matine / Nuageux dans l'aprs-midi",#  				,,,,,
	"AM Light Rain","Lgre pluie dans la matine",#  				"Lichte regen in de ochtend","vormittags leichter Regen","????","Dopoludnia slab d??","?????? ????? ?? ???????","?? ??????? ?????"
	"AM Light Rain / Wind","Lgre pluie dans la matine / Vent",#  				"Lichte regen en wind in de ochtend","vormittags leichter Regen / Wind","???????","Dopoludnia slab d?? / Vietor","?????? ????? ?? ??????? / ?????","?? ??????? ????? / ??????"
	"AM Light Snow","Lgres chutes de neige dans la matine",#  				"Lichte sneeuw in de ochtend","vormittags leichter Schneefall","????","Dopoludnia slab sne?enie","?????? ???? ?? ???????","?? ??????? ??????????"
	"AM Light Snow / Wind","Lgres chutes de neige dans la matine / Vent",#  				"Lichte sneeuw en wind in de ochtend","vormittags leichter Schneefall und windig","???????","Dopoludnia slab sne?enie / Vietor","?????? ???? ?? ??????? / ?????","?? ??????? ?????????? / ??????"
	"AM Light Wintry Mix","Lgres prcipitations hivernales dans la matine",#  				"Lichte winterse neerslag in de ochtend","vormittags leichte Mischung aus Schnee und Regen","???????","Dopoludnia sychravo","?????? ????? ? ????????? ? ???? ?? ???????","?? ??????? ?????????"
	"AM Rain","Pluie dans la matine",#  				"Regen in de ochtend","vormittags Regen","????","Dopoludnia d??","????? ?? ???????","?? ?????"
	"AM Rain / Ice","Pluie dans la matine / Glace",#  				"Regen / IJzel in de ochtend","vormittags Regen / Eis","???????","Dopoludnia d?? / ?ad","????? ?? ??????? / ???","?? ????? / ?????"
	"AM Rain / Snow","Pluie dans la matine / Neige",#  				"Regen / sneeuw in de ochtend","vormittags Regen / Schnee","???????","Dopoludnia d?? / Sne?enie","????? ?? ??????? / ????","?? ????? / ?????"
	"AM Rain / Snow / Wind","Pluie dans la matine / Neige / Vent",#  				"Regen / sneeuw en wind in de ochtend","vormittags Regen / Schnee / Wind","??????????","Dopoludnia d?? / Sne?enie / Vietor","????? ?? ??????? / ???? / ?????","?? ????? / ????? / ??????"
	"AM Rain / Snow Showers","Pluie / Chutes de neige dans la matine",#  				"Regen- en sneeuwbuien in de ochtend","vormittags Regen / Schneeschauer","???????","Dopoludnia d?? / Snehov prehnky","????? ?? ??????? / ???????? ????","?? ????? / ????????????"
	"AM Rain / Wind","Pluie dans la matine / Vent",#  				"Regen / wind in de ochtend","vormittags Regen / Wind","???????","Dopoludnia d?? / Vietor","????? ?? ??????? / ?????","?? ????? / ??????"
	"AM Showers","Averses dans la matine",#  				"Buien in de ochtend","vormittags Regenschauer","????","Dopoludnia prehnky","???????? ????? ?? ???????","?? ?????????"
	"AM Showers / Wind","Averses dans la matine / Vent",#  				"Buien / wind in de ochtend","vormittags Regenschauer / Wind","???????","Dopoludnia prehnky / Vietor","???????? ????? ?? ??????? / ?????","?? ????????? / ??????"
	"AM Snow","Neige dans la matine",#  				"Sneeuw in de ochtend","vormittags Schnee","????","Dopoludnia sne?enie","???? ?? ???????","?? ?????"
	"AM Snow Showers","Chutes de neige dans la matine",#  				"Sneeuwbuien in de ochtend","vormittags Schneeschauer","????","Dopoludnia snehov prehnky","???????? ???? ?? ???????","?? ????????????"
	"AM Snow Showers / Wind","Chutes de neige dans la matine / Vent",#  				"Sneeuwbuien / wind in de ochtend","vormittags Schneeschauer / Wind","???????","Dopoludnia snehov prehnky / Vietor","???????? ???? ?? ??????? / ?????","?? ???????????? / ??????"
	"AM T-Storms","Orages dans la matine",#  				"Onweersbuien in de ochtend","vormittags Gewitter","??????","Dopoludnia brky","????? ?? ???????","?? ??????????"
	"AM Wintry Mix","Prcipitations hivernales dans la matine",#  				"Winterse neerslag in de ochtend","vormittags Mischung aus Schnee und Regen","????","Dopoludnia chladno a sychravo","????? ? ????????? ? ???? ?? ???????","?? ?????????"
	"Blowing Sand and Windy","Rafales de sable et Vent",#  				"Opwaaiend zand en winderig","Sandwehen und windig","????","Zvren piesok a veterno","???????? ???? ? ???????","??????????"
	"Blowing Snow","Rafales de neige",#  				"Opwaaiende sneeuw","Schneewehen","??","Zvren sneh (tvorba zvejov)","??????","???????????"
	"Clear","Ciel dgag",#  				"Onbewolkt","wolkenlos","??","Jasno","????","???????"
	"Clouds Early / Clearing Late","Nuageux d'abord / claircie ensuite",#  				"Eerst bewolkt, later opklaringen","anfangs bewlkt, spter aufklarend","???/???","Spo?iatku obla?no / Neskr jasno","?????? ????? / ???? ???????","????????? ????? / ??????? ????????"
	"Cloudy","Nuageux",#  				"Bewolkt","bewlkt","?","Zamra?en","???????","?????????"
	"Cloudy / Wind","Nuageux / Vent",#  				"Bewolkt / wind","bewlkt / Wind","????","Zamra?en / Vietor","??????? / ?????","????????? / ??????"
	"Cloudy and Windy","Nuageux et Venteux",#  				"Bewolkt en winderig","bewlkt und windig","????","Zamra?en a veterno","??????? ? ???????","????????? ?? ?????"
	"Drifting Snow","Rafales de neige",#  				,,,,,
	"Drizzle","Bruine",#  				"Motregen","Nieselregen","???","Mrholenie","????????","??????"
	"Drizzle / Fog","Bruine / Brouillard",#  				,,,,,
	"Fair","Beau",#  				"Licht bewolkt","heiter","???","Pekne","????","???????"
	"Fair and Windy","Beau et Venteux",#  				"Licht bewolkt en winderig","heiter und windig","??????","Pekne a veterno","???? ? ???????","??????? ?? ?????"
	"Few Showers","Quelques averses",#  				"Een paar buien","einige Regenschauer","????","Ojedinel prehnky","??????????????? ???????? ?????","???????? ??????"
	"Few Showers / Wind","Quelques averses / Vent",#  				"Een paar buien / wind","einige Regenschauer / Wind","???????","Ojedinel prehnky / Vietor","??????????????? ???????? ????? / ?????","????? ??????/ ??????"
	"Few Snow Showers","Quelques chutes de neige",#  				"Een paar sneeuwbuien","einige Schneeschauer","????","Ojedinel snehov prehnky","??????????????? ???????? ????","????? ????????????"
	"Few Snow Showers / Wind","Quelques chutes de neige / Vent",#  				"Een paar sneeuwbuien / wind","einige Schneeschauer / Wind","???????","Ojedinel snehov prehnky / Vietor","??????????????? ???????? ???? / ?????","????? ???????????? / ??????"
	"Flurries","Chutes de neige fondante",#  				"Stuifsneeuw","Ben","??","Nepriaznivo - ?lapkanica","?????","???????"
	"Flurries / Wind","Chutes de neige fondante / Vent",#  				"Stuifsneeuw / wind","Ben / Wind","?????","Nepriaznivo - ?lapkanica / Vietor","????? / ?????","??????? / ??????"
	"Fog","Brouillard",#  				"Mist","Nebel","?","Hmla (vidite?nos? do 1 km)","?????","??????"
	"Fog / Clouds","Brouillard / Ciel se couvrant",#  				,,,,,
	"Fog Early / Clearing Late","Brouillard d'abord / claircie ensuite",#  				,,,,,
	"Foggy","Brouillard",#  				,,,,,
	"Freezing Rain","Pluie verglaante",#  				,,,,"??????? ?????","???????? ?????"
	"Haze","Lgre brume",#  				"Heiigheid","Dunst","?","Hmla (vidite?nos? do 10 km)","?????","????????"
	"Heavy Drizzle","Forte bruine",#  				,,,,"??????? ????????","?????? ??????"
	"Heavy Rain","Forte pluie",#  				"Zware regen","starker Regen","??","Siln da??","??????? ?????","?????????"
	"Heavy Rain / Wind","Forte pluie / Vent",#  				"Zware regen / wind","starker Regen / Wind","?????","Siln da?? / Vietor","??????? ????? / ?????","????????? / ??????"
	"Heavy Rain Shower","Fortes averses",#  				"Zware regenbui","starker Regenschauer","???","Siln da??ov prehnky","?????????? ???????? ?????","?????? ?????????"
	"Heavy Rain Shower and Windy","Fortes averses et Vent",#  				"Zware regenbui en winderig","starker Regenschauer und windig","??????","Siln da??ov prehnky a veterno","?????????? ???????? ????? ? ???????","?????? ????????? ?? ?????"
	"Heavy Snow","Fortes chutes de neige",#  				"Zware sneeuwval","starker Schneefall","??","Siln sne?enie","??????? ????","?????? ??????????"
	"Heavy T-Storm","Orage violent",#  				"Zware onweersbui","starke Gewitter","???","Siln brky",,
	"Heavy T-Storm and Windy","Orage violent et Vent",#  				"Zware onweersbui en winderig","starke Gewitter und windig","??????","Siln brky a veterno","??????? ????? ? ???????","?????? ????????? ?? ?????"
	"Heavy T-Storms","Orages violents",#  				"Zware onweersbuien","starke Gewitter","???","Siln brky","??????? ?????","?????? ?????????"
	"Heavy T-Storms / Wind","Orages violents / Vent",#  				"Zware onweersbuien / wind","starke Gewitter / Wind","??????","Siln brky / Vietor","??????? ????? / ?????","?????? ????????? / ??????"
	"Heavy Rain / Freezing Rain","Forte pluie / Pluie verglaante",#  				"Zware regen / IJzel","starker Regen / Eisregen","?????","Siln d?? / Mrznci d??","??????? ????? / ??????? ?????","??????? ?????? / ???????? ?????"
	"Ice to Rain","Givre puis Pluie",#  				"IJsregen, overgaand in regen","Eisregen, in Regen bergehend","????","Mrznci d?? meniaci sa na d??","???? ? ??????","????? ?? ?????"
	"Iso T-Storms / Wind","Orages isols / Vent",#  				"Gesoleerde onweersbuien / wind","vereinzelt Gewitter / Wind","???????","Ob?asn brky / Vietor","????? ????????, ?? ???????????? / ?????","??????????? ?????????? / ??????"
	"Isolated T-Storms","Orages isols",#  				"Gesoleerde onweersbuien","vereinzelt Gewitter","????","Ob?asn brky","????? ????????, ?? ????????????","??????????? ??????????"
	"Light Drizzle","Lgre bruine",#  				"Lichte motregen","leichter Nieselregen","??","Slab mrholenie","?????? ????????","??????? ??????"
	"Light Freezing Drizzle","Lgre bruine verglaante",#  				,,,,"?????? ??????? ????????","??????? ???????? ??????"
	"Light Freezing Rain","Lgre pluie verglaante",#  				,,,,"?????? ??????? ?????","??????? ???????? ?????"
	"Light Rain","Lgre pluie",#  				"Lichte regen","leichter Regen","??","Slab d??","?????? ?????","??????? ?????"
	"Light Rain / Fog","Lgre pluie / Brouillard",#  				,,,,,
	"Light Rain / Freezing Rain","Lgre pluie / Pluie verglaante",#  				"Lichte regen of ijzel","leichter bis gefrierender Regen","?????","Slab d?? / Mrznci d??","?????? ????? / ??????? ?????","??????? ????? / ???????? ?????"
	"Light Rain / Wind","Lgre pluie / Vent",#  				"Lichte regen en wind","leichter Regen / Wind","?????","Slab d?? / Vietor","?????? ????? / ?????","??????? ????? / ??????"
	"Light Rain and Fog","Lgre pluie et Brouillard",#  				,,,,,
	"Light Rain and Freezing Rain","Lgre pluie et Pluie verglaante",#  				,,,,"?????? ? ??????? ?????","??????? ????? ??? ???????? ?????"
	"Light Rain and Windy","Lgre pluie et Vent",#  				"Lichte regen / wind","leichter Regen und Wind","?????","Slab d?? a veterno","?????? ????? ? ???????","??????? ????? ?? ?????"
	"Light Rain Shower","Lgres averses",#  				"Lichte regenbui","leichter Regenschauer","???","Slab da??ov prehnky","?????? ???????? ?????","??????? ?????????"
	"Light Rain Shower and Fog","Lgre pluie et brouillard",#  				,,,,,
	"Light Rain Shower and Windy","Lgres averses et Vent",#  				"Lichte regenbui en winderig","leichter Regenschauer und windig","?????","Slab da??ov prehnky / Veterno","?????? ???????? ????? ? ???????","??????? ????????? ?? ?????"
	"Light Rain with Thunder","Lgre pluie avec tonnerre",#  				"Lichte regen met onweer","leichter Regen mit Donner","????","Slab d?? s brou","?????? ????? ? ??????","???????? ????? ?? ?????????"
	"Light Snow","Lgres chutes de neige",#  				"Lichte sneeuwval","leichter Schneefall","??","Slab sne?enie","?????? ????","??????? ??????????"
	"Light Snow / Fog","Lgres chutes de neige / Brouillard",#  				,,,,,
	"Light Snow / Wind","Lgre neige / Vent",#  				"Lichte sneeuw / wind","leichter Schneefall / Wind","?????","Slab sne?enie / vietor","?????? ???? / ?????","??????? ?????????? / ??????"
	"Light Snow and Fog","Lgre neige et Brouillard",#  				"Lichte sneeuwval en mist","leichter Schneefall und Nebel","????","Slab sne?enie a hmla (vidite?nos? do 1 km)","?????? ???? ? ?????","??????? ?????????? ??? ??????"
	"Light Snow Grains","Lgers granules de neige",#  				"Lichte korrelsneeuw","leichtes Schneegrieseln","???","Slab snehov zrn","?????? ??????? ?????","???????? ???????"
	"Light Snow Grains and Fog","Lgers granules de neige et Brouillard",#  				,,,,,
	"Light Snow Late","Lgres chutes de neige",#  				"Later lichte sneeuwval","spter leichter Schneefall","????","Slab neskor sne?enie","?????? ???? ???????","??????? ?????????? ????"
	"Light Snow Shower","Lgres chutes de neige",#  				"Lichte sneeuwbui","leichter Schneeschauer","???","Slab snehov prehnky","?????? ???????? ????","??????? ??????????"
	"Light Snow Shower / Wind","Lgres chutes de neige / Vent",#  				"Lichte sneeuwbui / wind","leichter Schneeschauer / Wind","?????","Slab snehov prehnky / Vietor","?????? ???????? ???? / ?????","??????? ?????????? / ??????"
	"Mist","Brume",#  				"Nevel","Nebel","?","Dymno bez vodnch pr (vidite?nos? do 1 km)","????????","????????"
	"Mostly Clear","Ciel plutt dgag",#  				"Overwegend onbewolkt","berwiegend wolkenlos","????","Preva?ne jasno","? ???????? ????","?????? ???????"
	"Mostly Clear / Wind","Ciel plutt dgag / Vent",#  				"Overwegend onbewolkt / wind","berwiegend wolkenlos / Wind","??????","Preva?ne jasno / Vietor","? ???????? ???? / ?????","?????? ??????? / ??????"
	"Mostly Cloudy","Plutt nuageux",#  				"Overwegend bewolkt","berwiegend bewlkt","????","Preva?ne zamra?en","??????? ? ????????????","?????? ?????????"
	"Mostly Cloudy / Wind","Plutt nuageux / Vent",#  				"Overwegend bewolkt / wind","berwiegend bewlkt / Wind","??????","Preva?ne zamra?en / Vietor","??????? ? ???????????? / ?????","?????? ????????? / ??????"
	"Mostly Cloudy and Windy","Plutt nuageux et Venteux",#  				"Overwegend bewolkt en winderig","berwiegend bewlkt und windig","???????","Preva?ne zamra?en a veterno","??????? ? ???????????? ? ???????","?????? ????????? ?? ?????"
	"Mostly Sunny","Plutt ensoleill",#  				"Overwegend zonnig","berwiegend sonnig","????","Preva?ne slne?no","? ???????? ????????","?????? ???????????"
	"Mostly Sunny / Wind","Plutt ensoleill / Vent",#  				"Overwegend zonnig / wind","berwiegend sonnig / Wind","??????","Preva?ne slne?no / Vietor","? ???????? ???????? / ?????","?????? ??????????? / ??????"
	"Partly Cloudy","Passages nuageux",#  				"Licht bewolkt","teilweise wolkig","??","Obla?no","????????? ??????????","??????? ?????????"
	"Partly Cloudy / Wind","Passages nuageux / Vent",#  				"Licht bewolkt / wind","teilweise wolkig / Wind","?????","Obla?no / Vietor","????????? ?????????? / ?????","??????? ????????? / ??????"
	"Partly Cloudy and Windy","Passages nuageux et Vent",#  				"Licht bewolkt en winderig","teilweise wolkig und windig","?????","Obla?no a veterno","????????? ?????????? ? ???????","??????? ????????? ?? ?????",
	"Partly Sunny","Partiellement ensoleill",# nouveau
	"Patches of Fog","Bancs de brouillard",#  				,,,,"??????? ?????","??????? ???????"
	"PM Drizzle","Bruine dans l'aprs-midi",#  				"In de middag motregen","nachmittags Nieselregen","?????","Popoludn mrholenie","???????? ????? ???????","?? ??????"
	"PM Fog","Brouillard dans l'aprs-midi",#  				,,,,,
	"PM Light Rain","Lgre pluie dans l'aprs-midi",#  				"In de middag lichte regen","nachmittags leichter Regen","????","Popoludn slab d??","?????? ????? ????? ???????","?? ??????? ?????"
	"PM Light Rain / Ice","Lgre pluie dans l'aprs-midi / Verglas",#  				"In de middag lichte regen / ijsregen","nachmittags leichter Regen / Eis","???????","Popoludn slab d?? / ?ad","?????? ????? ????? ??????? / ???","?? ??????? ????? / ?????"
	"PM Light Rain / Wind","Lgre pluie dans l'aprs-midi / Vent",#  				"In de middag lichte regen / wind","nachmittags leichter Regen / Wind","???????","Popoludn slab d?? / Vietor","?????? ????? ????? ??????? / ?????","?? ??????? ????? / ??????"
	"PM Light Snow","Lgres chutes de neige dans l'aprs-midi",#  				"In de middag lichte sneeuw","nachmittags leichter Schneefall","????","Popoludn slab sne?enie","?????? ???? ????? ???????","?? ??????? ??????????"
	"PM Light Snow / Wind","Lgres chutes de neige dans l'aprs-midi / Vent",#  				"In de middag lichte sneeuw / wind","nachmittags leichter Schneefall / Wind","???????","Popoludn slab sne?enie / Vietor","?????? ???? ????? ??????? / ?????","?? ??????? ?????????? / ??????"
	"PM Rain","Pluie dans l'aprs-midi",#  				"In de middag regen","nachmittags Regen","????","Popoludn d??","????? ????? ???????","?? ?????"
	"PM Rain / Snow","Pluie / Neige dans l'aprs-midi",#  				"In de middag regen / sneeuw","nachmittags Regen / Schnee","???????","Popoludn d?? / Sne?enie","????? ????? ??????? / ????","?? ????? / ?????"
	"PM Rain / Snow / Wind","Pluie / Neige / Vent dans l'aprs-midi",#  				"In de middag regen / sneeuw / wind","nachmittags Regen / Schnee / Wind","??????????","Popoludn d?? / Sne?enie / Vietor","????? ????? ??????? / ???? / ?????","?? ????? / ????? / ??????"
	"PM Rain / Snow Showers","Pluie / Chutes de neige dans l'aprs-midi",#  				"In de middag regen / sneeuwbuien","nachmittags Regen / Schneeschauer","???????","Popoludn d?? / Snehov prehnky","????? ????? ??????? / ???????? ????","?? ????? / ????????????"
	"PM Showers","Averses dans l'aprs-midi",#  				"In de middag buien","nachmittags Regenschauer","????","Popoludn prehnky","???????? ????? ????? ???????","?? ??????"
	"PM Showers / Wind","Averses / Vent dans l'aprs-midi",#  				"In de middag buien / wind","nachmittags Regenschauer / Wind","???????","Popoludn prehnky / Vietor","???????? ????? ????? ??????? / ?????","?? ?????? / ??????"
	"PM Snow","Chutes de neige dans l'aprs-midi",#  				"In de middag sneeuw","nachmittags Schneefall","????","Popoludn sne?enie","???? ????? ???????","?? ?????"
	"PM Snow / Wind","Chutes de neige dans l'aprs-midi / Vent",#  				"In de middag sneeuw / wind","nachmittags Schneefall / Wind","???????","Popoludn sne?enie / Vietor","???? ????? ??????? / ?????","?? ????? / ??????"
	"PM Snow Showers","Chutes de neige dans l'aprs-midi",#  				"In de middag sneeuwbuien","nachmittags Schneeschauer","????","Popoludn snehov prehnky","???????? ???? ????? ???????","?? ????????????"
	"PM Snow Showers / Wind","Chutes de neige dans l'aprs-midi / Vent",#  				"In de middag sneeuwbuien / wind","nachmittags Schneeschauer / Wind","???????","Popoludn snehov prehnky / Vietor","???????? ???? ????? ??????? / ?????","?? ???????????? / ??????"
	"PM T-Showers","Averses orageuses dans l'aprs-midi",#  				,,,,,
	"PM T-Storms","Orages dans l'aprs-midi",#  				"In de middag onweersbuien","nachmittags Gewitter","??????","Popoludn brky","????? ????? ???????","?? ??????????"
	"PM Wintry Mix","Prcipitations hivernales dans l'aprs-midi",#  				"In de middag winterse neerslag","nachmittags Mischung aus Schnee und Regen","??????","Popoludn chladno a sychravo","????? ? ????????? ? ???? ????? ???????","?? ?????????"
	"Rain","Pluie",#  				"Regen","Regen","?","D??","?????","?????"
	"Rain / Freezing Rain","Pluie / Pluie verglaante",#  				"Regen / IJzel","Regen / Eisregen","?????","D?? / Mrznci d??","????? / ??????? ?????","????? / ???????? ?????"
	"Rain / Sleet","Pluie / Granules de glace",#  				"Regen / natte sneeuw","Regen / Schneeregen","????","D?d / Krpy ","????? / ???????","????? / ?????????"
	"Rain / Snow","Pluie / Neige",#  				"Regen / sneeuw","Regen / Schnee","????","D?? / Sne?enie","????? / ????","????? / ?????"
	"Rain / Snow / Wind","Pluie / Neige / Vent",#  				"Regen / sneeuw / wind","Regen / Schnee / Wind","???????","D?? / Sne?enie / Vietor","????? / ???? / ?????","????? / ????? / ??????"
	"Rain / Snow Showers","Pluie / Chutes de neige",#  				"Regen / sneeuwbuien","Regen / Schneeschauer","????","D?? / Snehov prehnky","????? / ???????? ????","????? / ????????????"
	"Rain / Snow Showers / Wind","Pluie / Chutes de neige / Vent",#  				"Regen / sneeuwbuien / wind","Regen / Schneeschauer / Wind","???????","D?? / Snehov prehnky / Vietor","????? / ???????? ???? / ?????","????? / ???????????? / ??????"
	"Rain / Snow Showers Late","Pluie / Chutes de neige",#  				"Regen / later sneeuwbuien","spter Regen / Schneeschauer","???????","D?? / Neskr snehov prehnky","????? / ???????? ???? ???????","????? / ???????????? ????"
	"Rain / Thunder","Pluie / Tonnerre",#  				"Regen / onweer","Regen / Donner","????","D?? / Hrmenie","????? / ????","????? / ????????"
	"Rain / Thunder / Wind","Pluie / Tonnerre / Vent",#  				"Regen / onweer / wind","Regen / Donner / Wind","???????","D?? / Hrmenie / Vietor","????? / ???? / ?????","????? / ???????? / ??????"
	"Rain / Wind","Pluie / Vent",#  				"Regen / wind","Regen / Wind","????","D?? / Vietor","????? / ?????","????? / ??????"
	"Rain and Sleet","Pluie et Granules de glace",#  				"Regen en natte sneeuw","Regen und Graupelschauer","?????","D?? a krpy","????? ? ???????","????? ??? ?????????"
	"Rain and Snow","Pluie et Neige",#  				"Regen en sneeuw","Regen und Schnee","???","D?? a sne?enie","????? ? ????","????? ??? ?????"
	"Rain Shower","Averses",#  				"Regenbui","Regenschauer","??","Da??ov prehnky","???????? ?????","?????????"
	"Rain Shower and Windy","Averses et Vent",#  				"Regenbui en winderig","Regenschauer und windig","?????","D?? / ?lapkanica","???????? ????? ? ???????","????????? ?? ?????"
	"Rain to Snow","Pluie devenant neige",#  				"Regen overgaand in sneeuw","Regen, in Schnee bergehend","???","D?? so snehom","????? ?? ??????","????? ???? ?????"
	"Rain to Snow / Wind","Pluie devenant neige / Vent",#  				"Regen overgaand in sneeuw / wind","Regen, in Schnee bergehend / Wind","??????","D?d so snehom / Vietor ","????? ?? ?????? / ?????","????? ???? ????? / ??????"
	"Scattered Flurries","Chutes de neige fondante parses",#  				"Hier en daar wat stuifsneeuw","stellenweise Ben","????","Ojedinelo ?lapkanica","???????? ?????","?????????? ???????"
	"Scattered Flurries / Wind","Chutes de neige fondante parses / Vent",#  				"Hier en daar wat stuifsneeuw / wind","stellenweise Ben / Wind","???????","Ojedinelo ?lapkanica / Vietor","???????? ????? / ?????","?????????? ??????? / ??????"
	"Scattered Showers","Averses parses",#  				"Hier en daar buien","stellenweise Regenschauer","????","Ojedinel prehnky","???????? ???????? ?????","?????????? ??????"
	"Scattered Showers / Wind","Averses parses / Vent",#  				"Hier en daar buien / wind","stellenweise Regenschauer / Wind","???????","Ojedinel prehnky / Vietor","???????? ???????? ????? / ?????","?????????? ?????? / ??????"
	"Scattered Snow Showers","Alternance de chutes de neige",#  				"Hier en daar sneeuwbuien","stellenweise Schneeschauer","????","Ojedinel snehov prehnky","???????? ???????? ????","?????????? ????????????"
	"Scattered Snow Showers / Wind","Chutes de neige parses / Vent",#  				"Hier en daar sneeuwbuien / wind","stellenweise Schneeschauer / Wind","???????","Ojedinel snehov prehnky / Vietor","???????? ???????? ???? / ?????","?????????? ???????????? / ??????"
	"Scattered Strong Storms","Orages violents pars",#  				"Hier en daar zware buien","stellenweise schwere Strme","??????","Ojedinel siln brky","???????? ??????? ?????","?????????? ??????? ??????????"
	"Scattered T-Storms","Orages pars",#  								"Hier en daar onweersbuien","stellenweise Gewitter","????","Ojedinel brky","???????? ?????","?????????? ??????????"
	"Scattered T-Storms / Wind","Orages pars / Vent",#  								"Hier en daar onweersbuien / wind","stellenweise Gewitter / Wind","???????","Ojedinel brky / Vietor","???????? ????? / ?????","?????????? ?????????? / ??????"
	"Shallow Fog","Brouillard",#  								,,,,,
	"Showers","Averses",#  								"Buien","Regenschauer","????","Prehnky","???????? ?????","?????????"
	"Showers / Wind","Averses / Vent",#  								"Buien / wind","Regenschauer / Wind","?????","Prehnky / Vietor","???????? ????? / ?????","????????? / ??????"
	"Showers / Wind Late","Averses / Vent",#  								"Buien / later wind","spter Regenschauer / Wind","???????","Prehnky / Neskr veterno","???????? ????? / ????? ???????","????????? / ?????? ????"
	"Showers Early","Averses",#  								"Vroeg buien","anfangs Regenschauer","????","Spo?iatku prehnky","???????? ????? ?????","????????? ?????"
	"Showers in the Vicinity","Averses dans le voisinage",#  								"Buien in de nabijheid","Regenschauer in der Umgebung","?????","Blzka prehnka","???????? ????? ? ????????????","?????? ??? ???? ??????"
	"Showers Late","Averses",#  								"Later buien","spter Regenschauer","????","Neskor prehnky","???????? ????? ???????","????????? ????"
	"Sleet","Granules de glace ",#  				,,,,"???????","?????????"
	"Smoke","Fume",#  				"Rook","Dunst","?","Dymov clona","???","??????"
	"Snow","Neige",#  				"Sneeuw","Schnee","?","Sne?enie","????","?????"
	"Snow / Wind","Neige / Vent",#  				"Sneeuw / wind","Schnee / Wind","????","Sne?enie / Vietor","???? / ?????","Snow / ??????"
	"Snow and Fog","Neige et Brouillard",#  				,,,,,
	"Snow and Ice to Rain","Neige et Glace puis Pluie",#  				"Sneeuw / ijsregen, overgaand in regen","Schnee und Eis, bergehend in Regen","?????","Sne?enie a mrznci d?? meniaci sa na d??","???? ? ???? ? ??????","????? ??? ????? ?? ?????"
	"Snow Grains","Granules de neige",#  				"Korrelsneeuw","Schneegrieseln","??","Snehov zrn","??????? ?????","????????????"
	"Snow Shower","Chutes de neige",#  				"Sneeuwbui","Schneeschauer","??","Snehov prehnky","???????? ????","????????????"
	"Snow Shower / Wind","Chutes de neige / Vent",#  				"Sneeuwbuien / wind","Schneeschauer / Wind","?????","Snehov prehnky / Vietor","???????? ???? / ?????","???????????? / ??????"
	"Snow Shower / Wind Early","Chutes de neige / Vent",#  				"Sneeuwbuien / vroeg wind","anfangs Schneeschauer / Wind","??????","Snehov prehnky / Spo?iatku vietor","???????? ???? / ????? ?????","???????????? / ?????? ?????"
	"Snow Showers Early","Chutes de neige",#  				"Vroeg sneeuwbuien","anfangs Schneeschauer","????","Spo?iatku snehov prehnky","???????? ???? ?????","???????????? ?????"
	"Snow Showers Late","Chutes de neige",#  				"Later sneeuwbuien","spter Schneeschauer","????","Neskor snehov prehnky","???????? ???? ???????","???????????? ????"
	"Snow to Ice","Neige puis Verglas",#  				"Sneeuw, overgaand in ijsregen","Schnee, bergehend in Eis","???","Snehov krpy","???? ? ??????","????? ?? ????"
	"Snow to Ice / Wind","Neige se transformant en glace / Vent",#  				"Sneeuw, overgaand in ijsregen / wind","Schnee, bergehend in Eis / Wind","??????","Snehov krpy / Vietor","???? ? ?????? / ?????","????? ?? ???? / ??????"
	"Snow to Rain","Neige puis Pluie",#  				"Sneeuw, overgaand in regen","Schnee, bergehend in Regen","???","Sne?enie meniace sa na d??","???? ? ??????","????? ?? ?????"
	"Snow to Rain / Wind","Neige puis Pluie / Vent",#  				"Sneeuw, overgaand in regen / wind","Schnee, bergehend in Regen / Wind","??????","Sne?enie meniace sa na d?? / Vietor","???? ? ?????? / ?????","????? ?? ????? / ??????"
	"Snow to Wintry Mix","Neige puis Prcipitations hivernales",#  				"Sneeuw, overgaand in natte sneeuw","Schnee, bergehend in Schneeregen oder Regen","??????","Chladno a sychravo so sne?enm","???? ? ????????? ? ?????","????? ?? ?????????"
	"Sprinkles","Averses",#  				"Lichte buitjes","leichter Regen","???","Prehnky","????????? ?????","?????????"
	"Strong Storms","Orages violents",#  				"Zware buien","starke Strme","????","Siln brky","??????? ?????","??????? ???????"
	"Strong Storms / Wind","Orages violents / Vent",#  				"Zware buien / wind","starke Strme / Wind","???????","Siln brky / Vietor","??????? ????? / ?????","??????? ??????? / ??????"
	"Sunny","Ensoleill",#  				"Zonnig","sonnig","?","Slne?no","????????","???????????"
	"Sunny / Wind","Ensoleill / Vent",#  				"Zonnig / wind","sonnig / Wind","????","Slne?no / Vietor","???????? / ?????","??????????? / ??????"
	"Sunny and Windy","Ensoleill et Venteux",#  				"Zonnig / winderig","sonnig / windig","????","Slne?no / Vietor","???????? / ???????","??????????? / ??????"
	"T-Showers","Averses orageuses",#  				"Onweersbuien","strmische Regenschauer","???","Prehnky","???????? ???????? ?????","??????????"
	"T-Showers / Wind","Averses orageuses / Vent",#  				"Onweersbuien / wind","strmische Regenschauer / Wind","?????","Prehnky / Vietor","???????? ???????? ????? / ?????","?????????? / ??????"
	"T-Storm","Orage",#  				"Zware onweersbui","Gewitter","??","Brka","?????","?????????"
	"T-Storms","Orages",#  				"Zware onweersbuien","Gewitter","????","Brky","?????","??????????"
	"T-Storms / Wind","Orages / Vent",#  				"Zware onweersbuien / wind","Gewitter / Wind","???????","Brky / Vietor","????? / ?????","?????????? / ??????"
	"T-Storms Early","Orages",#  				"Vroeg zware onweersbuien","anfangs Gewitter","??????","Spo?iatku brky","????? ?????","?????????? ?????"
	"T-Storms Late","Orages",#  				"Later zware onweersbuien","spter Gewitter","??????","Neskor brky","????? ???????","?????????? ????"
	"Thunder","Tonnerre",#  				"Onweer","Gewitter","??","Brka","????","????????"
	"Thunder and Wintry Mix","Tonnerre et Prcipitations hivernales",#  				"Onweer en Winterse neerslag","Gewitter und Mischung aus Schnee und Regen","???????","Chladno a sychravo s brkou","???? ? ????? ? ????????? ? ????","???????? ??? ?????????"
	"Thunder in the Vicinity","Tonnerre dans le voisinage",#  				"Onweer in de nabijheid","Gewitter in der Umgebung","?????","Blzka brka","???? ? ????????????","???????? ??? ???? ??????"
	"Unknown Precip","Prcipitations",#  				,,,,,
	"Widespread Dust","Brume sche",#  				"Stof, wijdverspreid","Schwebender Staub","???","Rozsiahle pra?no","???????? ??????? ????","??????? ?????"
	"Wintry Mix","Prcipitations hivernales",#  				"Winterse neerslag","Mischung aus Schnee und Regen","????","Chladno a sychravo","????? ? ????????? ? ????","?????????"
	"Wintry Mix / Wind","Prcipitations hivernales / Vent",#  				"Winterse neerslag / wind","Mischung aus Schnee und Regen / Wind","???????","Chladno a sychravo / Vietor","????? ? ????????? ? ???? / ?????","????????? / ??????"
	"Wintry Mix to Snow","Prcipitations hivernales puis Neige",#  				"Natte sneeuw, overgaand in sneeuw","Mischung aus Schnee und Regen, bergehend in Schnee","??????","Chladno a sychravo so sne?enm","????? ? ????????? ? ????","????????? ?? ?????"
         "Overcast", "Brouillard bas",
	"Lgt.snow/fog", "lgres chutes de neige et brouillard",
	"Snow/rain", "Pluie et neige mle",
	"Snowshower","Averses de neige",
	"Lgt.snowshower", "Lgres chutes de neige" ,
	"Light Fog", "Lger brouillard",
	"Ground Fog", "Stratus");





  #conversions / mapping
    if ( exists $weathers { $mythoutput {"weather"}}) {
    	$mythoutput {"weather"} = $weathers {$mythoutput {"weather"}}; }

    else  { };




  #icon mappings to be made
             my %icons = ("01","sunny.png",
			  "02","sunny.png",
	   		  "03","sunny.png",
	 		  "04","pcloudy.png",
	 		  "05","pcloudy.png",
			  "06","mcloudy.png",
			  "07","mcloudy.png",
			  "08","cloudy.png",
			  "11","fog.png",
			  "12","lshowers.png",
			  "13","lshowers.png",
			  "14","showers.png",
			  "15","thunshowers.png",
			  "16","thunshowers.png",
			  "17","thunshowers.png",
			  "18","showers.png",
			  "19","snowshow.png",
			  "20","snowshow.png",
			  "21","sunny.png",
			  "22","snowshow.png",
			  "23","snowshow.png",
			  "24","snowshow.png",
			  "25","lshowers.png",
			  "26","lshowers.png",
			  "27","unknown.png",
			  "28","unknown.png",
			  "29","rainsnow.png",
			  "30","sunny.png",
			  "31","snowshow.png",
			  "32","unknown.png",
			  "33","fair.png",
			  "34","fair.png",
			  "35","fair.png",
			  "36","fair.png",
			  "37","fair.png",
			  "38","fair.png",
			  "39","lshowers.png",
			  "40","lshowers.png",
			  "41","thunshowers.png",
			  "43","lshowers.png",
			  "44","flurries.png",
			  "45","flurries.png",
			  "45","unknown.png",
			  "46","fair.png");

	# conversions icon/ mapping
		if ( exists $icons { $mythoutput {"weather_icon"}}) {
			$mythoutput {"weather_icon"} = $icons {$mythoutput {"weather_icon"}}; }
		else { $mythoutput {"weather_icon"} = "unknown.png" ; }
			$mythoutput {"relative_humidity"} =~ s/%// ;

	# conversions m/s en km/h for the windspeed
		$mythoutput {"windgust"} = $mythoutput {"wind_gust"}*3.60 ;
		$mythoutput {"windspdgst"} = $mythoutput {"wind_spdgst"}*3.60 ;
		$mythoutput {"wind_gust"} = $mythoutput {"windgust"} ;
		$mythoutput {"wind_spdgst"} = $mythoutput {"windspdgst"} ;
		$mythoutput {"wind_spdgst"} .= " (" . $mythoutput {"wind_gust"} . ")" ;


	# download forecast 3/6 days
		my $i;
		for ($i = 0; $i < 6; ++$i) {

			$mythoutput{"date-" . $i} = $xml->{forecast}->{day}->[$i]->{daycode} ;
			$mythoutput{"icon-" . $i} = $xml->{forecast}->{day}->[$i]->{daytime}->{weathericon} ;
			$mythoutput{"low-" . $i} = $xml->{forecast}->{day}->[$i]->{daytime}->{lowtemperature} ;
			$mythoutput{"high-" . $i} = $xml->{forecast}->{day}->[$i]->{daytime}->{hightemperature} ;

			if ( exists $daycodes { $mythoutput {"date-" . $i}}) {
				$mythoutput {"date-" . $i} = $daycodes {$mythoutput {"date-" . $i}}; }
			else { $mythoutput {"date-" . $i} = "Inconnu" ; }


			if ( exists $icons { $mythoutput {"icon-" . $i}}) {
				$mythoutput {"icon-" . $i} = $icons {$mythoutput {"icon-" . $i}}; }
			else { $mythoutput {"icon-" . $i} = "unknown.png" ; }
		}


	#output the data

		foreach $keyword (@types)
		{ $value = $mythoutput{$keyword}; 
		if (ref($value) eq 'HASH'){
			printf "%s::%s\n",$keyword,$value->{content};
		}
		else {
		printf "%s::%s\n",$keyword,$value;
		}
}
